pub struct ParachainBlockImport<Block: BlockT, BI, BE> { /* private fields */ }Expand description
Parachain specific block import.
This is used to set block_import_params.fork_choice to false as long as the block origin is
not NetworkInitialSync. The best block for parachains is determined by the relay chain.
Meaning we will update the best block, as it is included by the relay-chain.
Implementations
sourceimpl<Block: BlockT, BI, BE: Backend<Block>> ParachainBlockImport<Block, BI, BE>
impl<Block: BlockT, BI, BE: Backend<Block>> ParachainBlockImport<Block, BI, BE>
sourcepub fn new(inner: BI, backend: Arc<BE>) -> Self
pub fn new(inner: BI, backend: Arc<BE>) -> Self
Create a new instance.
The number of leaves per level limit is set to LevelLimit::Default.
sourcepub fn new_with_limit(
inner: BI,
backend: Arc<BE>,
level_leaves_max: LevelLimit
) -> Self
pub fn new_with_limit( inner: BI, backend: Arc<BE>, level_leaves_max: LevelLimit ) -> Self
Create a new instance with an explicit limit to the number of leaves per level.
This function alone doesn’t enforce the limit on levels for old imported blocks, the limit is eventually enforced only when new blocks are imported.